from setuptools import setup

setup(
    name='geneCGR',
    version='1.1',
    description='A test PyPI package',
    author='akhil',
    author_email='cppractice000@gmail.com',
    packages=['geneCGR'],
)
